@@ -2,6 +2,7 @@
 import logging
 
 from luxtronik.datatypes import (
+    Kelvin,
     Celsius,
     CoolingMode,
     HeatingMode,
@@ -95,7 +96,7 @@ class Parameters:
         71: Unknown("ID_Einst_TVL_Std_8"),
         72: Unknown("ID_Einst_TVL_Std_9"),
         73: Unknown("ID_Einst_TVL_Std_10"),
-        74: Unknown("ID_Einst_BWS_Hyst_akt"),
+        74: Kelvin("ID_Einst_BWS_Hyst_akt", True),
         75: Unknown("ID_Temp_TBW_BwHD_saved"),
         76: Unknown("ID_Einst_ABT1_akt"),
         77: Unknown("ID_Einst_LABTpaus_akt"),
@@ -1147,6 +1148,7 @@ class Parameters:
         1123: Unknown("Unknown_Parameter_1123"),
         1124: Unknown("Unknown_Parameter_1124"),
         1125: Unknown("Unknown_Parameter_1125"),
+        1126: Unknown("Unknown_Parameter_1126"),
     }
 
     def __init__(self, safe=True):
